@@ -22,18 +22,32 @@
 #include "bootconfig.h"
 
 /* basic data types and constants */
-#ifdef __linux__
+#if defined(__linux__)
 typedef unsigned char u8;
 typedef unsigned short u16;
 typedef unsigned int u32;
-#endif
+#define isblank(a) ( ( a == ' ' ) || ( a == '\t' ) )
+#elif defined( __QNXNTO__ )
+#include <stdint.h>
+typedef uint8_t u8;
+typedef uint16_t u16;
+typedef uint32_t u32;
+#define isblank(a) ( ( a == ' ' ) || ( a == '\t' ) )
+#endif /* linux or qnx */ 
+
+
 typedef unsigned char  byte;
 typedef unsigned short word;
 typedef unsigned int   dword;
 typedef void *vaddr_t;
 typedef unsigned long paddr_t;
-
+typedef unsigned long u_int32_t;
+typedef unsigned long pd_entry_t;
+#if defined(__linux__) || defined(__QNXNTO__)
+#include <stddef.h>
+#else
 typedef long size_t;
+#endif
 
 typedef void (*vfuncp)(void);
 
@@ -44,9 +58,15 @@ typedef void (*vfuncp)(void);
 #define CTL_REG_READ_BYTE(addr)	    (*(volatile unsigned char *)(addr))
 #define CTL_REG_WRITE_BYTE(addr, val)    (*(volatile unsigned char *)(addr) = (val))
 
+#ifndef TRUE
 #define TRUE           1
+#endif
+#ifndef FALSE
 #define FALSE          0
+#endif
+#ifndef NULL
 #define NULL           ((void *) 0)
+#endif
 
 /* bootloader delay time */
 #define TIMEOUT        350000
@@ -107,9 +127,10 @@ flash as folows:
 #define BOOTLDR_END             (BOOTLDR_START+BOOTLDR_SIZE)
 #define VBOOTLDR_START          (UNCACHED_FLASH_BASE+BOOTLDR_OFFSET)
 #define VBOOTLDR_END            (VBOOTLDR_START+BOOTLDR_SIZE)
-#endif
+#endif /* DeadCode */
 
 enum bootblk_flags {
+    BB_NONE = 0,
     BB_RUN_FROM_RAM = 1
 };
 
@@ -118,7 +139,6 @@ struct bootblk_command {
     void (*cmdfunc)(int argc, const char **);
     const char *helpstr;
     enum bootblk_flags flags;
-    
 };
 
 #define DEFAULT_XMODEM_BLOCK_SIZE 1024            /* default size of transmit blocks */
@@ -140,30 +160,53 @@ extern long xmodem_block_size;
 #define MACH_TYPE_OMNIMETER 49
 #define MACH_TYPE_SPOT 53
 #define MACH_TYPE_GATOR 103
+#define MACH_TYPE_JORNADA56X 167
+#define MACH_TYPE_H3900 203
+#define MACH_TYPE_PXA1  204
+#define MACH_TYPE_H5400 220
 
-#ifdef CONFIG_ASSABET
+#ifdef CONFIG_MACH_ASSABET
 #define MACH_TYPE MACH_TYPE_ASSABET
 #endif
-#ifdef CONFIG_BITSY
+#ifdef CONFIG_MACH_IPAQ
 #define MACH_TYPE MACH_TYPE_H3600
 #endif
-#ifdef CONFIG_JORNADA720
+#ifdef CONFIG_MACH_JORNADA720
 #define MACH_TYPE MACH_TYPE_JORNADA720
 #endif
+#ifdef CONFIG_MACH_JORNADA56X
+#define MACH_TYPE MACH_TYPE_JORNADA56X
+#endif
 #ifdef CONFIG_OMNIMETER
 #define MACH_TYPE MACH_TYPE_OMNIMETER
 #endif
-#ifdef CONFIG_SKIFF
+#ifdef CONFIG_MACH_SKIFF
 #define MACH_TYPE MACH_TYPE_PERSONAL_SERVER
 #endif
-#ifdef CONFIG_SPOT
+#ifdef CONFIG_MACH_SPOT
 #define MACH_TYPE MACH_TYPE_SPOT
 #endif
-#ifdef CONFIG_GATOR
+#ifdef CONFIG_MACH_GATOR
 #define MACH_TYPE MACH_TYPE_GATOR
 #endif
+#ifdef CONFIG_MACH_H3900
+#define MACH_TYPE MACH_TYPE_H3900
+#endif
+#ifdef CONFIG_PXA1
+#define MACH_TYPE MACH_TYPE_PXA1
+#endif
+#ifdef CONFIG_MACH_IPAQ3
+#define MACH_TYPE MACH_TYPE_IPAQ3
+#endif
 
 void initialize_by_mach_type(void);
+#define machine_is_h3600() (param_mach_type.value == MACH_TYPE_H3600)
+#define machine_is_h3100() (param_mach_type.value == MACH_TYPE_H3100)
+#define machine_is_h3800() ((param_mach_type.value == MACH_TYPE_H3800) || (*boot_flags_ptr & BF_H3800))
+#define machine_is_h3900() ((param_mach_type.value == MACH_TYPE_H3900) || (*boot_flags_ptr & BF_H3900))
+#define machine_is_h5400() ((param_mach_type.value == MACH_TYPE_H5400) || (*boot_flags_ptr & BF_H5400))
+#define	machine_is_jornada56x()	(param_mach_type.value == MACH_TYPE_JORNADA56X || ((*boot_flags_ptr) & BF_JORNADA56X))
+
 
 /* External Functions - written in assembler [boot.s] */
 void boot(void *bootinfo,long startaddr);
@@ -174,22 +217,23 @@ void *memcpy(char *dst, const char *src, long n);
 int  memcmp(const char *buf1,const char *buf2, long n);
 #endif
 unsigned long strtoul(const char *str, char **endptr, int requestedbase);
-char *strchr(const char *str, char c);
+//char *strchr(const char *str, char c);
+// char *strrchr(const char *str, char c);
 char *strcat(char *dst, const char *str);
-int strncmp(const char *s1, const char *s2, int len);
+int strcmp(const char *s1, const char *s2);
+//int strncmp(const char *s1, const char *s2, int len);
+int memmem(const char *haystack,int num1, const char *needle,int num2);
+unsigned long strtoul(const char *str, char **endptr, int requestedbase);
 
 void PrintChar(char c, void *uart); 
-void putc(char c);
-void putstr(const char *str);
-void putnstr(const char *str, size_t n);
 void putLabeledWord(const char *msg, unsigned long value);
 void putHexInt32(unsigned long value);
 void putHexInt16(word value);
 void putHexInt8(byte value);
-byte getc(void);
-byte awaitkey(unsigned long delay, int *error_p);
+void delay_seconds(unsigned long seconds);
 void binary_dld(unsigned long img_size, unsigned long img_dest);
 void dwordtodecimal(char *buf, unsigned long x);
+void hex_dump(unsigned char *data, size_t num);
 
 long get_system_rev();
 void program_all_eeprom();
@@ -213,17 +257,20 @@ unsigned long readCPR3(void);
 unsigned long readCPR4(void);
 unsigned long readCPR5(void);
 unsigned long readCPR6(void);
+unsigned long readCPR7(void);
+unsigned long readCPR8(void);
+unsigned long readCPR9(void);
+unsigned long readCPR10(void);
 unsigned long readCPR13(void);
 unsigned long readCPR14(void);
+unsigned long readCPR15(void);
+
+
+/* PocketPCSE */
+void disableWriteDataCaching(void);
 
 
 
-extern void
-let_uart_drain(
-    unsigned long status_addr);
-
-#define	let_uart_drain0()    let_uart_drain(SA1100_UART3_UTSR1)
-
 extern void
 exec_string(
     char*   buf);
@@ -233,9 +280,6 @@ push_cmd_chars(
     char*   chars,
     int	    len);
 
-extern void set_egpio(int mask);
-extern void clr_egpio(int mask);
-
 #include "boot_flags.h"
 
 #define	BL_ISPRINT(ch)	    (((ch)>=' ') && ((ch) < 128))
@@ -261,5 +305,35 @@ print_mem_size(
     char*   hdr,
     long    mem_size);
 
+extern void
+bootldr_reset(
+	      void);
+
+extern unsigned char amRunningFromRam(void);
+#if defined(CONFIG_LOAD_KERNEL)
+extern void boot_kernel(const char *root_filesystem_name, 
+                        vaddr_t kernel_region_start, size_t kernel_region_size, int argc, const char **argv, int no_copy);
+#endif
+
+extern void putstr(const char *s);
+int body_testJFFS2(const char *filename,unsigned long *dest);
+int body_infoJFFS2(char *partname);
+int body_timeFlashRead(char *partname);
+long body_p1_load_file(const char *partname,const char *filename,unsigned char *dest);
+int body_p1_ls(char *dir,char *partname);
+void body_cmpKernels(const char *partname,unsigned long *dstFlash,unsigned long *srcJFFS,unsigned long len);
+void body_clearMem(unsigned long num,unsigned short *dst);
+unsigned char isWincePartition(unsigned char *p);
+unsigned char amRunningFromRam(void);
+void print_version_verbose(char* prefix);
+void unparseargs(char *argstr, int argc, const char **argv);
+
+#ifdef __QNXNTO__
+char *strncpy( char *__s1, const char *__s2, size_t __n );
+#endif
+
+typedef unsigned char BOOL;
+BOOL isValidBootloader(unsigned long p,unsigned long size);
+
 #endif /* _BOOTLDR_H_ */
 
