@@ -10,7 +10,7 @@
 #include "mmu.h"
 #include "params.h"
 #include "zlib.h"
-#if defined(__linux__) || defined(__QNXNTO__)
+#if CONFIG_MACH_IPAQ
 #include <asm-arm/arch-sa1100/h3600_gpio.h>
 #include <asm-arm/arch-sa1100/h3600_asic.h>	
 #endif
