@@ -9,6 +9,12 @@ enum LFR_FLAGS {
    LFR_KERNEL = 4,		/* add BOOTIMG_MAGIC, imgsize and VKERNEL_BASE to head of programmed region (see bootldr.c) */
    LFR_EXPAND = 8,              /* expand partition size to fit rest of flash */
    LFR_JFFS2 = 16               /* erase whole partition, format unwritten sectors so JFFS2 won't re-erase and format */
+#if defined(CONFIG_NAND)
+   ,LFR_NAND = 32               /* found in a NAND chip not bootable NOR */
+#if defined(CONFIG_YAFFS)
+   ,LFR_NAND_YAFFS = 64         /* write yaffs images */
+#endif
+#endif
 };
 
 #define FLASH_PARTITION_NAMELEN 32
